@@ -266,7 +266,7 @@ void fEBBinaryMexBfNeEN(int *Used, double *Mu2, double *SIGMA2, double *H2, doub
 		fEBDeltaMLBfNeEN(DeltaML, Action, AlphaRoot,anyToDelete,Used, Unused, S_out, Q_out, Alpha,
 				a_lambda, b_Alpha, N_used, N_unused);
 		//
-        deltaLogMarginal			= 0;
+        deltaLogMarginal			= 0.001;
         nu							= -1;
         for(i=0;i<M_full;i++)
         {
@@ -347,9 +347,12 @@ void fEBBinaryMexBfNeEN(int *Used, double *Mu2, double *SIGMA2, double *H2, doub
 			//Rprintf("\t\t newAlpha: %f\n",newAlpha);
             // B_phi*PHI2*SIGMA2        tmp = B_phi*PHI2 
             index					= N_used + 1;
-			if(index >basisMax && iter>1) {
-				Rprintf("out of Memory!\n");
-				return;
+			if(index > (basisMax -10) && iter>1 && (N*K) > 1e7) {
+				Rprintf("bases: %d, warning: out of Memory!\n",index);
+			}//return;
+			if(index > (basisMax -1) && iter>1 && (N*K) > 1e7) {
+				Rprintf("bases: %d, out of Memory,exiting program!\n",index);
+				//exit(1);			
 			}
             for(i=0;i<index;i++)
             {
@@ -609,6 +612,7 @@ void LinearSolverBfNeEN(double * a, double *logout, int N, int M,double *output)
 	const int lwork	= M*N + 4*N;
 	double * work;
 	work				= (double *) Calloc(lwork,double);
+
 	int info			= 0;
 	// *************************Call LAPACK library ************************
 	F77_CALL(dgelsy)(&N, &M, &nrhs, a, &N, logout, &N,jpvt,&Rcond, &rank, work, &lwork,&info);
@@ -617,13 +621,15 @@ void LinearSolverBfNeEN(double * a, double *logout, int N, int M,double *output)
 		Rprintf("Call linear solver degls error!\n");
 		return;
 	}
-	
 	//Rprintf("Matrix inversed!\n");	
-	int i;
+	//int i;
 	//output				= (double *) realloc(NULL,M*sizeof(double));
-	for (i=0;i<M;i++) output[i] = logout[i];	
-		Free(jpvt);
-	Free(work);	
+	//for (i=0;i<M;i++) output[i] = logout[i];	
+	int inci = 1;
+	int incj = 1;
+	F77_CALL(dcopy)(&M,logout,&inci,output,&incj);
+	Free(jpvt);
+	Free(work);
 }
 
  /// ***********************************************************************************************   
