@@ -475,8 +475,8 @@ if(verbose >3) Rprintf("check point 3: before loop \n");
 			//Rprintf("\t\t newAlpha: %f\n",newAlpha);
             // B_phi*PHI2*SIGMA2        tmp = B_phi*PHI2 
             index					= M + 1;
-			if(index > (basisMax -10)) {
-				Rprintf("bases: %d, warning: out of Memory, alloc more to Neffect!\n",index);
+			if(index > (basisMax -10) && (N*K) > 1e7) {
+				Rprintf("bases: %d, warning: out of Memory!\n",index);
 			}//return;
 			//BASIS_B_Phi	=BASIS_Phi*beta;
 			UPDATE_REQUIRED		= ActionAddGmNeg(BASIS_PHI, BASIS, Scales, PHI, phi, beta, Alpha,
